# coding: utf-8

# flake8: noqa

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from orcid_api_v3.api.development_member_api_v3_0_api import DevelopmentMemberAPIV30Api
from orcid_api_v3.api.development_member_api_v3_0_rc1_api import DevelopmentMemberAPIV30Rc1Api
from orcid_api_v3.api.development_member_api_v3_0_rc2_api import DevelopmentMemberAPIV30Rc2Api
from orcid_api_v3.api.member_api_v2_0_api import MemberAPIV20Api
from orcid_api_v3.api.member_api_v2_1_api import MemberAPIV21Api
# import ApiClient
from orcid_api_v3.api_client import ApiClient
from orcid_api_v3.configuration import Configuration
# import models into sdk package
from orcid_api_v3.models.activities_summary_v20 import ActivitiesSummaryV20
from orcid_api_v3.models.activities_summary_v30 import ActivitiesSummaryV30
from orcid_api_v3.models.activities_summary_v30_rc1 import ActivitiesSummaryV30Rc1
from orcid_api_v3.models.activities_summary_v30_rc2 import ActivitiesSummaryV30Rc2
from orcid_api_v3.models.address_v20 import AddressV20
from orcid_api_v3.models.address_v30 import AddressV30
from orcid_api_v3.models.address_v30_rc1 import AddressV30Rc1
from orcid_api_v3.models.address_v30_rc2 import AddressV30Rc2
from orcid_api_v3.models.addresses_v20 import AddressesV20
from orcid_api_v3.models.addresses_v30 import AddressesV30
from orcid_api_v3.models.addresses_v30_rc1 import AddressesV30Rc1
from orcid_api_v3.models.addresses_v30_rc2 import AddressesV30Rc2
from orcid_api_v3.models.affiliation_group_v30 import AffiliationGroupV30
from orcid_api_v3.models.affiliation_group_v30_distinction_summary_v30 import AffiliationGroupV30DistinctionSummaryV30
from orcid_api_v3.models.affiliation_group_v30_education_summary_v30 import AffiliationGroupV30EducationSummaryV30
from orcid_api_v3.models.affiliation_group_v30_employment_summary_v30 import AffiliationGroupV30EmploymentSummaryV30
from orcid_api_v3.models.affiliation_group_v30_invited_position_summary_v30 import AffiliationGroupV30InvitedPositionSummaryV30
from orcid_api_v3.models.affiliation_group_v30_membership_summary_v30 import AffiliationGroupV30MembershipSummaryV30
from orcid_api_v3.models.affiliation_group_v30_qualification_summary_v30 import AffiliationGroupV30QualificationSummaryV30
from orcid_api_v3.models.affiliation_group_v30_rc1 import AffiliationGroupV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_distinction_summary_v30_rc1 import AffiliationGroupV30Rc1DistinctionSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_education_summary_v30_rc1 import AffiliationGroupV30Rc1EducationSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_employment_summary_v30_rc1 import AffiliationGroupV30Rc1EmploymentSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_invited_position_summary_v30_rc1 import AffiliationGroupV30Rc1InvitedPositionSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_membership_summary_v30_rc1 import AffiliationGroupV30Rc1MembershipSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_qualification_summary_v30_rc1 import AffiliationGroupV30Rc1QualificationSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc1_service_summary_v30_rc1 import AffiliationGroupV30Rc1ServiceSummaryV30Rc1
from orcid_api_v3.models.affiliation_group_v30_rc2 import AffiliationGroupV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_distinction_summary_v30_rc2 import AffiliationGroupV30Rc2DistinctionSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_education_summary_v30_rc2 import AffiliationGroupV30Rc2EducationSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_employment_summary_v30_rc2 import AffiliationGroupV30Rc2EmploymentSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_invited_position_summary_v30_rc2 import AffiliationGroupV30Rc2InvitedPositionSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_membership_summary_v30_rc2 import AffiliationGroupV30Rc2MembershipSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_qualification_summary_v30_rc2 import AffiliationGroupV30Rc2QualificationSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_rc2_service_summary_v30_rc2 import AffiliationGroupV30Rc2ServiceSummaryV30Rc2
from orcid_api_v3.models.affiliation_group_v30_service_summary_v30 import AffiliationGroupV30ServiceSummaryV30
from orcid_api_v3.models.affiliation_summary_v30 import AffiliationSummaryV30
from orcid_api_v3.models.affiliation_summary_v30_rc1 import AffiliationSummaryV30Rc1
from orcid_api_v3.models.affiliation_summary_v30_rc2 import AffiliationSummaryV30Rc2
from orcid_api_v3.models.amount_v20 import AmountV20
from orcid_api_v3.models.amount_v30 import AmountV30
from orcid_api_v3.models.amount_v30_rc1 import AmountV30Rc1
from orcid_api_v3.models.amount_v30_rc2 import AmountV30Rc2
from orcid_api_v3.models.authorization_url_v20 import AuthorizationUrlV20
from orcid_api_v3.models.authorization_url_v30 import AuthorizationUrlV30
from orcid_api_v3.models.authorization_url_v30_rc1 import AuthorizationUrlV30Rc1
from orcid_api_v3.models.authorization_url_v30_rc2 import AuthorizationUrlV30Rc2
from orcid_api_v3.models.biography_v20 import BiographyV20
from orcid_api_v3.models.biography_v30 import BiographyV30
from orcid_api_v3.models.biography_v30_rc1 import BiographyV30Rc1
from orcid_api_v3.models.biography_v30_rc2 import BiographyV30Rc2
from orcid_api_v3.models.bulk_element import BulkElement
from orcid_api_v3.models.citation import Citation
from orcid_api_v3.models.client_summary import ClientSummary
from orcid_api_v3.models.completion_date_v20 import CompletionDateV20
from orcid_api_v3.models.completion_date_v30 import CompletionDateV30
from orcid_api_v3.models.completion_date_v30_rc1 import CompletionDateV30Rc1
from orcid_api_v3.models.completion_date_v30_rc2 import CompletionDateV30Rc2
from orcid_api_v3.models.contributor_attributes_v30 import ContributorAttributesV30
from orcid_api_v3.models.contributor_attributes_v30_rc1 import ContributorAttributesV30Rc1
from orcid_api_v3.models.contributor_attributes_v30_rc2 import ContributorAttributesV30Rc2
from orcid_api_v3.models.contributor_email_v20 import ContributorEmailV20
from orcid_api_v3.models.contributor_email_v30 import ContributorEmailV30
from orcid_api_v3.models.contributor_email_v30_rc1 import ContributorEmailV30Rc1
from orcid_api_v3.models.contributor_email_v30_rc2 import ContributorEmailV30Rc2
from orcid_api_v3.models.contributor_orcid_v20 import ContributorOrcidV20
from orcid_api_v3.models.contributor_orcid_v30 import ContributorOrcidV30
from orcid_api_v3.models.contributor_orcid_v30_rc1 import ContributorOrcidV30Rc1
from orcid_api_v3.models.contributor_orcid_v30_rc2 import ContributorOrcidV30Rc2
from orcid_api_v3.models.contributor_v20 import ContributorV20
from orcid_api_v3.models.contributor_v30 import ContributorV30
from orcid_api_v3.models.contributor_v30_rc1 import ContributorV30Rc1
from orcid_api_v3.models.contributor_v30_rc2 import ContributorV30Rc2
from orcid_api_v3.models.country_v20 import CountryV20
from orcid_api_v3.models.country_v30 import CountryV30
from orcid_api_v3.models.country_v30_rc1 import CountryV30Rc1
from orcid_api_v3.models.country_v30_rc2 import CountryV30Rc2
from orcid_api_v3.models.created_date_v20 import CreatedDateV20
from orcid_api_v3.models.created_date_v30 import CreatedDateV30
from orcid_api_v3.models.created_date_v30_rc1 import CreatedDateV30Rc1
from orcid_api_v3.models.created_date_v30_rc2 import CreatedDateV30Rc2
from orcid_api_v3.models.credit_name_v20 import CreditNameV20
from orcid_api_v3.models.credit_name_v30 import CreditNameV30
from orcid_api_v3.models.credit_name_v30_rc1 import CreditNameV30Rc1
from orcid_api_v3.models.credit_name_v30_rc2 import CreditNameV30Rc2
from orcid_api_v3.models.currency import Currency
from orcid_api_v3.models.day_v20 import DayV20
from orcid_api_v3.models.day_v30 import DayV30
from orcid_api_v3.models.day_v30_rc1 import DayV30Rc1
from orcid_api_v3.models.day_v30_rc2 import DayV30Rc2
from orcid_api_v3.models.deactivation_date_v20 import DeactivationDateV20
from orcid_api_v3.models.deactivation_date_v30 import DeactivationDateV30
from orcid_api_v3.models.deactivation_date_v30_rc1 import DeactivationDateV30Rc1
from orcid_api_v3.models.deactivation_date_v30_rc2 import DeactivationDateV30Rc2
from orcid_api_v3.models.disambiguated_organization_v20 import DisambiguatedOrganizationV20
from orcid_api_v3.models.disambiguated_organization_v30 import DisambiguatedOrganizationV30
from orcid_api_v3.models.disambiguated_organization_v30_rc1 import DisambiguatedOrganizationV30Rc1
from orcid_api_v3.models.disambiguated_organization_v30_rc2 import DisambiguatedOrganizationV30Rc2
from orcid_api_v3.models.distinction_summary_v30 import DistinctionSummaryV30
from orcid_api_v3.models.distinction_summary_v30_rc1 import DistinctionSummaryV30Rc1
from orcid_api_v3.models.distinction_summary_v30_rc2 import DistinctionSummaryV30Rc2
from orcid_api_v3.models.distinction_v30 import DistinctionV30
from orcid_api_v3.models.distinction_v30_rc1 import DistinctionV30Rc1
from orcid_api_v3.models.distinction_v30_rc2 import DistinctionV30Rc2
from orcid_api_v3.models.distinctions_summary_v30 import DistinctionsSummaryV30
from orcid_api_v3.models.distinctions_summary_v30_rc2 import DistinctionsSummaryV30Rc2
from orcid_api_v3.models.distinctions_v30_rc1 import DistinctionsV30Rc1
from orcid_api_v3.models.education_summary_v20 import EducationSummaryV20
from orcid_api_v3.models.education_summary_v30 import EducationSummaryV30
from orcid_api_v3.models.education_summary_v30_rc1 import EducationSummaryV30Rc1
from orcid_api_v3.models.education_summary_v30_rc2 import EducationSummaryV30Rc2
from orcid_api_v3.models.education_v20 import EducationV20
from orcid_api_v3.models.education_v30 import EducationV30
from orcid_api_v3.models.education_v30_rc1 import EducationV30Rc1
from orcid_api_v3.models.education_v30_rc2 import EducationV30Rc2
from orcid_api_v3.models.educations_summary_v20 import EducationsSummaryV20
from orcid_api_v3.models.educations_summary_v30 import EducationsSummaryV30
from orcid_api_v3.models.educations_summary_v30_rc1 import EducationsSummaryV30Rc1
from orcid_api_v3.models.educations_summary_v30_rc2 import EducationsSummaryV30Rc2
from orcid_api_v3.models.email_v20 import EmailV20
from orcid_api_v3.models.email_v30 import EmailV30
from orcid_api_v3.models.email_v30_rc1 import EmailV30Rc1
from orcid_api_v3.models.email_v30_rc2 import EmailV30Rc2
from orcid_api_v3.models.emails_v20 import EmailsV20
from orcid_api_v3.models.emails_v30 import EmailsV30
from orcid_api_v3.models.emails_v30_rc1 import EmailsV30Rc1
from orcid_api_v3.models.emails_v30_rc2 import EmailsV30Rc2
from orcid_api_v3.models.employment_summary_v20 import EmploymentSummaryV20
from orcid_api_v3.models.employment_summary_v30 import EmploymentSummaryV30
from orcid_api_v3.models.employment_summary_v30_rc1 import EmploymentSummaryV30Rc1
from orcid_api_v3.models.employment_summary_v30_rc2 import EmploymentSummaryV30Rc2
from orcid_api_v3.models.employment_v20 import EmploymentV20
from orcid_api_v3.models.employment_v30 import EmploymentV30
from orcid_api_v3.models.employment_v30_rc1 import EmploymentV30Rc1
from orcid_api_v3.models.employment_v30_rc2 import EmploymentV30Rc2
from orcid_api_v3.models.employments_summary_v20 import EmploymentsSummaryV20
from orcid_api_v3.models.employments_summary_v30 import EmploymentsSummaryV30
from orcid_api_v3.models.employments_summary_v30_rc1 import EmploymentsSummaryV30Rc1
from orcid_api_v3.models.employments_summary_v30_rc2 import EmploymentsSummaryV30Rc2
from orcid_api_v3.models.external_idv20 import ExternalIDV20
from orcid_api_v3.models.external_idv30 import ExternalIDV30
from orcid_api_v3.models.external_idv30_rc1 import ExternalIDV30Rc1
from orcid_api_v3.models.external_idv30_rc2 import ExternalIDV30Rc2
from orcid_api_v3.models.external_i_ds_v20 import ExternalIDsV20
from orcid_api_v3.models.external_i_ds_v30 import ExternalIDsV30
from orcid_api_v3.models.external_i_ds_v30_rc1 import ExternalIDsV30Rc1
from orcid_api_v3.models.external_i_ds_v30_rc2 import ExternalIDsV30Rc2
from orcid_api_v3.models.family_name_v20 import FamilyNameV20
from orcid_api_v3.models.family_name_v30 import FamilyNameV30
from orcid_api_v3.models.family_name_v30_rc1 import FamilyNameV30Rc1
from orcid_api_v3.models.family_name_v30_rc2 import FamilyNameV30Rc2
from orcid_api_v3.models.funding_contributor_attributes_v20 import FundingContributorAttributesV20
from orcid_api_v3.models.funding_contributor_attributes_v30 import FundingContributorAttributesV30
from orcid_api_v3.models.funding_contributor_attributes_v30_rc1 import FundingContributorAttributesV30Rc1
from orcid_api_v3.models.funding_contributor_attributes_v30_rc2 import FundingContributorAttributesV30Rc2
from orcid_api_v3.models.funding_contributor_v20 import FundingContributorV20
from orcid_api_v3.models.funding_contributor_v30 import FundingContributorV30
from orcid_api_v3.models.funding_contributor_v30_rc1 import FundingContributorV30Rc1
from orcid_api_v3.models.funding_contributor_v30_rc2 import FundingContributorV30Rc2
from orcid_api_v3.models.funding_contributors_v20 import FundingContributorsV20
from orcid_api_v3.models.funding_contributors_v30 import FundingContributorsV30
from orcid_api_v3.models.funding_contributors_v30_rc1 import FundingContributorsV30Rc1
from orcid_api_v3.models.funding_contributors_v30_rc2 import FundingContributorsV30Rc2
from orcid_api_v3.models.funding_group_v20 import FundingGroupV20
from orcid_api_v3.models.funding_group_v30 import FundingGroupV30
from orcid_api_v3.models.funding_group_v30_rc1 import FundingGroupV30Rc1
from orcid_api_v3.models.funding_group_v30_rc2 import FundingGroupV30Rc2
from orcid_api_v3.models.funding_summary_v20 import FundingSummaryV20
from orcid_api_v3.models.funding_summary_v30 import FundingSummaryV30
from orcid_api_v3.models.funding_summary_v30_rc1 import FundingSummaryV30Rc1
from orcid_api_v3.models.funding_summary_v30_rc2 import FundingSummaryV30Rc2
from orcid_api_v3.models.funding_title_v20 import FundingTitleV20
from orcid_api_v3.models.funding_title_v30 import FundingTitleV30
from orcid_api_v3.models.funding_title_v30_rc1 import FundingTitleV30Rc1
from orcid_api_v3.models.funding_title_v30_rc2 import FundingTitleV30Rc2
from orcid_api_v3.models.funding_v20 import FundingV20
from orcid_api_v3.models.funding_v30 import FundingV30
from orcid_api_v3.models.funding_v30_rc1 import FundingV30Rc1
from orcid_api_v3.models.funding_v30_rc2 import FundingV30Rc2
from orcid_api_v3.models.fundings_v20 import FundingsV20
from orcid_api_v3.models.fundings_v30 import FundingsV30
from orcid_api_v3.models.fundings_v30_rc1 import FundingsV30Rc1
from orcid_api_v3.models.fundings_v30_rc2 import FundingsV30Rc2
from orcid_api_v3.models.fuzzy_date_v20 import FuzzyDateV20
from orcid_api_v3.models.fuzzy_date_v30 import FuzzyDateV30
from orcid_api_v3.models.fuzzy_date_v30_rc1 import FuzzyDateV30Rc1
from orcid_api_v3.models.fuzzy_date_v30_rc2 import FuzzyDateV30Rc2
from orcid_api_v3.models.given_names_v20 import GivenNamesV20
from orcid_api_v3.models.given_names_v30 import GivenNamesV30
from orcid_api_v3.models.given_names_v30_rc1 import GivenNamesV30Rc1
from orcid_api_v3.models.given_names_v30_rc2 import GivenNamesV30Rc2
from orcid_api_v3.models.group_id_record import GroupIdRecord
from orcid_api_v3.models.group_id_records import GroupIdRecords
from orcid_api_v3.models.history_v20 import HistoryV20
from orcid_api_v3.models.history_v30 import HistoryV30
from orcid_api_v3.models.history_v30_rc1 import HistoryV30Rc1
from orcid_api_v3.models.history_v30_rc2 import HistoryV30Rc2
from orcid_api_v3.models.invited_position_summary_v30 import InvitedPositionSummaryV30
from orcid_api_v3.models.invited_position_summary_v30_rc1 import InvitedPositionSummaryV30Rc1
from orcid_api_v3.models.invited_position_summary_v30_rc2 import InvitedPositionSummaryV30Rc2
from orcid_api_v3.models.invited_position_v30 import InvitedPositionV30
from orcid_api_v3.models.invited_position_v30_rc1 import InvitedPositionV30Rc1
from orcid_api_v3.models.invited_position_v30_rc2 import InvitedPositionV30Rc2
from orcid_api_v3.models.invited_positions_v30 import InvitedPositionsV30
from orcid_api_v3.models.invited_positions_v30_rc1 import InvitedPositionsV30Rc1
from orcid_api_v3.models.invited_positions_v30_rc2 import InvitedPositionsV30Rc2
from orcid_api_v3.models.item_v20 import ItemV20
from orcid_api_v3.models.item_v30 import ItemV30
from orcid_api_v3.models.item_v30_rc1 import ItemV30Rc1
from orcid_api_v3.models.item_v30_rc2 import ItemV30Rc2
from orcid_api_v3.models.items_v20 import ItemsV20
from orcid_api_v3.models.items_v30 import ItemsV30
from orcid_api_v3.models.items_v30_rc1 import ItemsV30Rc1
from orcid_api_v3.models.items_v30_rc2 import ItemsV30Rc2
from orcid_api_v3.models.keyword_v20 import KeywordV20
from orcid_api_v3.models.keyword_v30 import KeywordV30
from orcid_api_v3.models.keyword_v30_rc1 import KeywordV30Rc1
from orcid_api_v3.models.keyword_v30_rc2 import KeywordV30Rc2
from orcid_api_v3.models.keywords_v20 import KeywordsV20
from orcid_api_v3.models.keywords_v30 import KeywordsV30
from orcid_api_v3.models.keywords_v30_rc1 import KeywordsV30Rc1
from orcid_api_v3.models.keywords_v30_rc2 import KeywordsV30Rc2
from orcid_api_v3.models.last_modified_date_v20 import LastModifiedDateV20
from orcid_api_v3.models.last_modified_date_v30 import LastModifiedDateV30
from orcid_api_v3.models.last_modified_date_v30_rc1 import LastModifiedDateV30Rc1
from orcid_api_v3.models.last_modified_date_v30_rc2 import LastModifiedDateV30Rc2
from orcid_api_v3.models.membership_summary_v30 import MembershipSummaryV30
from orcid_api_v3.models.membership_summary_v30_rc1 import MembershipSummaryV30Rc1
from orcid_api_v3.models.membership_summary_v30_rc2 import MembershipSummaryV30Rc2
from orcid_api_v3.models.membership_v30 import MembershipV30
from orcid_api_v3.models.membership_v30_rc1 import MembershipV30Rc1
from orcid_api_v3.models.membership_v30_rc2 import MembershipV30Rc2
from orcid_api_v3.models.memberships_v30 import MembershipsV30
from orcid_api_v3.models.memberships_v30_rc1 import MembershipsV30Rc1
from orcid_api_v3.models.memberships_v30_rc2 import MembershipsV30Rc2
from orcid_api_v3.models.month_v20 import MonthV20
from orcid_api_v3.models.month_v30 import MonthV30
from orcid_api_v3.models.month_v30_rc1 import MonthV30Rc1
from orcid_api_v3.models.month_v30_rc2 import MonthV30Rc2
from orcid_api_v3.models.name_v20 import NameV20
from orcid_api_v3.models.name_v30 import NameV30
from orcid_api_v3.models.name_v30_rc1 import NameV30Rc1
from orcid_api_v3.models.name_v30_rc2 import NameV30Rc2
from orcid_api_v3.models.notification import Notification
from orcid_api_v3.models.notification_permission_v20 import NotificationPermissionV20
from orcid_api_v3.models.notification_permission_v30 import NotificationPermissionV30
from orcid_api_v3.models.notification_permission_v30_rc1 import NotificationPermissionV30Rc1
from orcid_api_v3.models.notification_permission_v30_rc2 import NotificationPermissionV30Rc2
from orcid_api_v3.models.orcid_identifier_v20 import OrcidIdentifierV20
from orcid_api_v3.models.orcid_identifier_v30 import OrcidIdentifierV30
from orcid_api_v3.models.orcid_identifier_v30_rc1 import OrcidIdentifierV30Rc1
from orcid_api_v3.models.orcid_identifier_v30_rc2 import OrcidIdentifierV30Rc2
from orcid_api_v3.models.organization_address_v20 import OrganizationAddressV20
from orcid_api_v3.models.organization_address_v30 import OrganizationAddressV30
from orcid_api_v3.models.organization_address_v30_rc1 import OrganizationAddressV30Rc1
from orcid_api_v3.models.organization_address_v30_rc2 import OrganizationAddressV30Rc2
from orcid_api_v3.models.organization_defined_funding_sub_type_v20 import OrganizationDefinedFundingSubTypeV20
from orcid_api_v3.models.organization_defined_funding_sub_type_v30 import OrganizationDefinedFundingSubTypeV30
from orcid_api_v3.models.organization_defined_funding_sub_type_v30_rc1 import OrganizationDefinedFundingSubTypeV30Rc1
from orcid_api_v3.models.organization_defined_funding_sub_type_v30_rc2 import OrganizationDefinedFundingSubTypeV30Rc2
from orcid_api_v3.models.organization_v20 import OrganizationV20
from orcid_api_v3.models.organization_v30 import OrganizationV30
from orcid_api_v3.models.organization_v30_rc1 import OrganizationV30Rc1
from orcid_api_v3.models.organization_v30_rc2 import OrganizationV30Rc2
from orcid_api_v3.models.other_name_v20 import OtherNameV20
from orcid_api_v3.models.other_name_v30 import OtherNameV30
from orcid_api_v3.models.other_name_v30_rc1 import OtherNameV30Rc1
from orcid_api_v3.models.other_name_v30_rc2 import OtherNameV30Rc2
from orcid_api_v3.models.other_names_v20 import OtherNamesV20
from orcid_api_v3.models.other_names_v30 import OtherNamesV30
from orcid_api_v3.models.other_names_v30_rc1 import OtherNamesV30Rc1
from orcid_api_v3.models.other_names_v30_rc2 import OtherNamesV30Rc2
from orcid_api_v3.models.peer_review_duplicate_group_v30 import PeerReviewDuplicateGroupV30
from orcid_api_v3.models.peer_review_duplicate_group_v30_rc1 import PeerReviewDuplicateGroupV30Rc1
from orcid_api_v3.models.peer_review_duplicate_group_v30_rc2 import PeerReviewDuplicateGroupV30Rc2
from orcid_api_v3.models.peer_review_group_v20 import PeerReviewGroupV20
from orcid_api_v3.models.peer_review_group_v30 import PeerReviewGroupV30
from orcid_api_v3.models.peer_review_group_v30_rc1 import PeerReviewGroupV30Rc1
from orcid_api_v3.models.peer_review_group_v30_rc2 import PeerReviewGroupV30Rc2
from orcid_api_v3.models.peer_review_summary_v20 import PeerReviewSummaryV20
from orcid_api_v3.models.peer_review_summary_v30 import PeerReviewSummaryV30
from orcid_api_v3.models.peer_review_summary_v30_rc1 import PeerReviewSummaryV30Rc1
from orcid_api_v3.models.peer_review_summary_v30_rc2 import PeerReviewSummaryV30Rc2
from orcid_api_v3.models.peer_review_v20 import PeerReviewV20
from orcid_api_v3.models.peer_review_v30 import PeerReviewV30
from orcid_api_v3.models.peer_review_v30_rc1 import PeerReviewV30Rc1
from orcid_api_v3.models.peer_review_v30_rc2 import PeerReviewV30Rc2
from orcid_api_v3.models.peer_reviews_v20 import PeerReviewsV20
from orcid_api_v3.models.peer_reviews_v30 import PeerReviewsV30
from orcid_api_v3.models.peer_reviews_v30_rc1 import PeerReviewsV30Rc1
from orcid_api_v3.models.peer_reviews_v30_rc2 import PeerReviewsV30Rc2
from orcid_api_v3.models.person_external_identifier_v20 import PersonExternalIdentifierV20
from orcid_api_v3.models.person_external_identifier_v30 import PersonExternalIdentifierV30
from orcid_api_v3.models.person_external_identifier_v30_rc1 import PersonExternalIdentifierV30Rc1
from orcid_api_v3.models.person_external_identifier_v30_rc2 import PersonExternalIdentifierV30Rc2
from orcid_api_v3.models.person_external_identifiers_v20 import PersonExternalIdentifiersV20
from orcid_api_v3.models.person_external_identifiers_v30 import PersonExternalIdentifiersV30
from orcid_api_v3.models.person_external_identifiers_v30_rc1 import PersonExternalIdentifiersV30Rc1
from orcid_api_v3.models.person_external_identifiers_v30_rc2 import PersonExternalIdentifiersV30Rc2
from orcid_api_v3.models.person_v20 import PersonV20
from orcid_api_v3.models.person_v30 import PersonV30
from orcid_api_v3.models.person_v30_rc1 import PersonV30Rc1
from orcid_api_v3.models.person_v30_rc2 import PersonV30Rc2
from orcid_api_v3.models.personal_details_v20 import PersonalDetailsV20
from orcid_api_v3.models.personal_details_v30 import PersonalDetailsV30
from orcid_api_v3.models.personal_details_v30_rc1 import PersonalDetailsV30Rc1
from orcid_api_v3.models.personal_details_v30_rc2 import PersonalDetailsV30Rc2
from orcid_api_v3.models.preferences_v20 import PreferencesV20
from orcid_api_v3.models.preferences_v30 import PreferencesV30
from orcid_api_v3.models.preferences_v30_rc1 import PreferencesV30Rc1
from orcid_api_v3.models.preferences_v30_rc2 import PreferencesV30Rc2
from orcid_api_v3.models.publication_date_v20 import PublicationDateV20
from orcid_api_v3.models.publication_date_v30 import PublicationDateV30
from orcid_api_v3.models.publication_date_v30_rc1 import PublicationDateV30Rc1
from orcid_api_v3.models.publication_date_v30_rc2 import PublicationDateV30Rc2
from orcid_api_v3.models.qualification_summary_v30 import QualificationSummaryV30
from orcid_api_v3.models.qualification_summary_v30_rc1 import QualificationSummaryV30Rc1
from orcid_api_v3.models.qualification_summary_v30_rc2 import QualificationSummaryV30Rc2
from orcid_api_v3.models.qualification_v30 import QualificationV30
from orcid_api_v3.models.qualification_v30_rc1 import QualificationV30Rc1
from orcid_api_v3.models.qualification_v30_rc2 import QualificationV30Rc2
from orcid_api_v3.models.qualifications_v30 import QualificationsV30
from orcid_api_v3.models.qualifications_v30_rc1 import QualificationsV30Rc1
from orcid_api_v3.models.qualifications_v30_rc2 import QualificationsV30Rc2
from orcid_api_v3.models.record_v20 import RecordV20
from orcid_api_v3.models.record_v30 import RecordV30
from orcid_api_v3.models.record_v30_rc1 import RecordV30Rc1
from orcid_api_v3.models.record_v30_rc2 import RecordV30Rc2
from orcid_api_v3.models.research_resource_group_v30 import ResearchResourceGroupV30
from orcid_api_v3.models.research_resource_group_v30_rc1 import ResearchResourceGroupV30Rc1
from orcid_api_v3.models.research_resource_group_v30_rc2 import ResearchResourceGroupV30Rc2
from orcid_api_v3.models.research_resource_hosts_v30 import ResearchResourceHostsV30
from orcid_api_v3.models.research_resource_hosts_v30_rc1 import ResearchResourceHostsV30Rc1
from orcid_api_v3.models.research_resource_hosts_v30_rc2 import ResearchResourceHostsV30Rc2
from orcid_api_v3.models.research_resource_item_v30 import ResearchResourceItemV30
from orcid_api_v3.models.research_resource_item_v30_rc1 import ResearchResourceItemV30Rc1
from orcid_api_v3.models.research_resource_item_v30_rc2 import ResearchResourceItemV30Rc2
from orcid_api_v3.models.research_resource_proposal_v30 import ResearchResourceProposalV30
from orcid_api_v3.models.research_resource_proposal_v30_rc1 import ResearchResourceProposalV30Rc1
from orcid_api_v3.models.research_resource_proposal_v30_rc2 import ResearchResourceProposalV30Rc2
from orcid_api_v3.models.research_resource_summary_v30 import ResearchResourceSummaryV30
from orcid_api_v3.models.research_resource_summary_v30_rc1 import ResearchResourceSummaryV30Rc1
from orcid_api_v3.models.research_resource_summary_v30_rc2 import ResearchResourceSummaryV30Rc2
from orcid_api_v3.models.research_resource_title_v30 import ResearchResourceTitleV30
from orcid_api_v3.models.research_resource_title_v30_rc1 import ResearchResourceTitleV30Rc1
from orcid_api_v3.models.research_resource_title_v30_rc2 import ResearchResourceTitleV30Rc2
from orcid_api_v3.models.research_resource_v30 import ResearchResourceV30
from orcid_api_v3.models.research_resource_v30_rc1 import ResearchResourceV30Rc1
from orcid_api_v3.models.research_resource_v30_rc2 import ResearchResourceV30Rc2
from orcid_api_v3.models.research_resources_v30 import ResearchResourcesV30
from orcid_api_v3.models.research_resources_v30_rc1 import ResearchResourcesV30Rc1
from orcid_api_v3.models.research_resources_v30_rc2 import ResearchResourcesV30Rc2
from orcid_api_v3.models.researcher_url_v20 import ResearcherUrlV20
from orcid_api_v3.models.researcher_url_v30 import ResearcherUrlV30
from orcid_api_v3.models.researcher_url_v30_rc1 import ResearcherUrlV30Rc1
from orcid_api_v3.models.researcher_url_v30_rc2 import ResearcherUrlV30Rc2
from orcid_api_v3.models.researcher_urls_v20 import ResearcherUrlsV20
from orcid_api_v3.models.researcher_urls_v30 import ResearcherUrlsV30
from orcid_api_v3.models.researcher_urls_v30_rc1 import ResearcherUrlsV30Rc1
from orcid_api_v3.models.researcher_urls_v30_rc2 import ResearcherUrlsV30Rc2
from orcid_api_v3.models.result_v20 import ResultV20
from orcid_api_v3.models.result_v30 import ResultV30
from orcid_api_v3.models.result_v30_rc1 import ResultV30Rc1
from orcid_api_v3.models.result_v30_rc2 import ResultV30Rc2
from orcid_api_v3.models.search_v20 import SearchV20
from orcid_api_v3.models.search_v30 import SearchV30
from orcid_api_v3.models.search_v30_rc1 import SearchV30Rc1
from orcid_api_v3.models.search_v30_rc2 import SearchV30Rc2
from orcid_api_v3.models.service_summary_v30 import ServiceSummaryV30
from orcid_api_v3.models.service_summary_v30_rc1 import ServiceSummaryV30Rc1
from orcid_api_v3.models.service_summary_v30_rc2 import ServiceSummaryV30Rc2
from orcid_api_v3.models.service_v30 import ServiceV30
from orcid_api_v3.models.service_v30_rc1 import ServiceV30Rc1
from orcid_api_v3.models.service_v30_rc2 import ServiceV30Rc2
from orcid_api_v3.models.services_v30 import ServicesV30
from orcid_api_v3.models.services_v30_rc1 import ServicesV30Rc1
from orcid_api_v3.models.services_v30_rc2 import ServicesV30Rc2
from orcid_api_v3.models.source_client_id_v20 import SourceClientIdV20
from orcid_api_v3.models.source_client_id_v30 import SourceClientIdV30
from orcid_api_v3.models.source_client_id_v30_rc1 import SourceClientIdV30Rc1
from orcid_api_v3.models.source_client_id_v30_rc2 import SourceClientIdV30Rc2
from orcid_api_v3.models.source_name_v20 import SourceNameV20
from orcid_api_v3.models.source_name_v30 import SourceNameV30
from orcid_api_v3.models.source_name_v30_rc1 import SourceNameV30Rc1
from orcid_api_v3.models.source_name_v30_rc2 import SourceNameV30Rc2
from orcid_api_v3.models.source_orcid_v20 import SourceOrcidV20
from orcid_api_v3.models.source_orcid_v30 import SourceOrcidV30
from orcid_api_v3.models.source_orcid_v30_rc1 import SourceOrcidV30Rc1
from orcid_api_v3.models.source_orcid_v30_rc2 import SourceOrcidV30Rc2
from orcid_api_v3.models.source_v20 import SourceV20
from orcid_api_v3.models.source_v30 import SourceV30
from orcid_api_v3.models.source_v30_rc1 import SourceV30Rc1
from orcid_api_v3.models.source_v30_rc2 import SourceV30Rc2
from orcid_api_v3.models.subject_name_v30 import SubjectNameV30
from orcid_api_v3.models.subject_name_v30_rc2 import SubjectNameV30Rc2
from orcid_api_v3.models.submission_date_v20 import SubmissionDateV20
from orcid_api_v3.models.submission_date_v30 import SubmissionDateV30
from orcid_api_v3.models.submission_date_v30_rc1 import SubmissionDateV30Rc1
from orcid_api_v3.models.submission_date_v30_rc2 import SubmissionDateV30Rc2
from orcid_api_v3.models.subtitle_v20 import SubtitleV20
from orcid_api_v3.models.subtitle_v30 import SubtitleV30
from orcid_api_v3.models.subtitle_v30_rc1 import SubtitleV30Rc1
from orcid_api_v3.models.subtitle_v30_rc2 import SubtitleV30Rc2
from orcid_api_v3.models.title_v20 import TitleV20
from orcid_api_v3.models.title_v30 import TitleV30
from orcid_api_v3.models.title_v30_rc1 import TitleV30Rc1
from orcid_api_v3.models.title_v30_rc2 import TitleV30Rc2
from orcid_api_v3.models.transient_error import TransientError
from orcid_api_v3.models.transient_non_empty_string import TransientNonEmptyString
from orcid_api_v3.models.translated_title_v20 import TranslatedTitleV20
from orcid_api_v3.models.translated_title_v30 import TranslatedTitleV30
from orcid_api_v3.models.translated_title_v30_rc1 import TranslatedTitleV30Rc1
from orcid_api_v3.models.translated_title_v30_rc2 import TranslatedTitleV30Rc2
from orcid_api_v3.models.url_v20 import UrlV20
from orcid_api_v3.models.url_v30 import UrlV30
from orcid_api_v3.models.url_v30_rc1 import UrlV30Rc1
from orcid_api_v3.models.url_v30_rc2 import UrlV30Rc2
from orcid_api_v3.models.work_bulk_v20 import WorkBulkV20
from orcid_api_v3.models.work_bulk_v30 import WorkBulkV30
from orcid_api_v3.models.work_bulk_v30_rc1 import WorkBulkV30Rc1
from orcid_api_v3.models.work_bulk_v30_rc2 import WorkBulkV30Rc2
from orcid_api_v3.models.work_contributors_v20 import WorkContributorsV20
from orcid_api_v3.models.work_contributors_v30 import WorkContributorsV30
from orcid_api_v3.models.work_contributors_v30_rc1 import WorkContributorsV30Rc1
from orcid_api_v3.models.work_contributors_v30_rc2 import WorkContributorsV30Rc2
from orcid_api_v3.models.work_group_v20 import WorkGroupV20
from orcid_api_v3.models.work_group_v30 import WorkGroupV30
from orcid_api_v3.models.work_group_v30_rc1 import WorkGroupV30Rc1
from orcid_api_v3.models.work_group_v30_rc2 import WorkGroupV30Rc2
from orcid_api_v3.models.work_summary_v20 import WorkSummaryV20
from orcid_api_v3.models.work_summary_v30 import WorkSummaryV30
from orcid_api_v3.models.work_summary_v30_rc1 import WorkSummaryV30Rc1
from orcid_api_v3.models.work_summary_v30_rc2 import WorkSummaryV30Rc2
from orcid_api_v3.models.work_title_v20 import WorkTitleV20
from orcid_api_v3.models.work_title_v30 import WorkTitleV30
from orcid_api_v3.models.work_title_v30_rc1 import WorkTitleV30Rc1
from orcid_api_v3.models.work_title_v30_rc2 import WorkTitleV30Rc2
from orcid_api_v3.models.work_v20 import WorkV20
from orcid_api_v3.models.work_v30 import WorkV30
from orcid_api_v3.models.work_v30_rc1 import WorkV30Rc1
from orcid_api_v3.models.work_v30_rc2 import WorkV30Rc2
from orcid_api_v3.models.works_summary_v20 import WorksSummaryV20
from orcid_api_v3.models.works_summary_v30 import WorksSummaryV30
from orcid_api_v3.models.works_summary_v30_rc1 import WorksSummaryV30Rc1
from orcid_api_v3.models.works_summary_v30_rc2 import WorksSummaryV30Rc2
from orcid_api_v3.models.year_v20 import YearV20
from orcid_api_v3.models.year_v30 import YearV30
from orcid_api_v3.models.year_v30_rc1 import YearV30Rc1
from orcid_api_v3.models.year_v30_rc2 import YearV30Rc2



# -*- coding: utf-8 -*-
"""Tests for core functions."""

from flask_login import login_user
from urllib.parse import urlparse

from orcid_hub.models import OrcidToken, User
from orcid_hub.orcid_client import NestedDict
import json


def test_admin_view_access(request_ctx):
    """Test if SUPERUSER can run reports."""
    user = User.get(email="root@test0.edu")
    with request_ctx("/org_invitatin_summary") as ctx:
        login_user(user, remember=True)
        resp = ctx.app.full_dispatch_request()
        assert resp.status_code == 200
        assert b"<!DOCTYPE html>" in resp.data, "Expected HTML content"
        assert b"Organisation Invitation Summary" in resp.data
        assert b"root@test0.edu" in resp.data


def test_user_invitation_summary(request_ctx):
    """Test user invitation summary."""
    user = User.get(email="root@test0.edu")
    with request_ctx("/user_invitatin_summary") as ctx:
        login_user(user, remember=True)
        resp = ctx.app.full_dispatch_request()
        assert resp.status_code == 200
        assert b"<!DOCTYPE html>" in resp.data, "Expected HTML content"
        assert b"User Invitation Summary" in resp.data
        assert b"root@test0.edu" in resp.data


def test_user_summary(client):
    """Test user summary."""
    client.login_root()

    resp = client.get("/user_summary?from_date=2017-01-01&to_date=2018-02-28")
    assert resp.status_code == 200
    assert b"<!DOCTYPE html>" in resp.data, "Expected HTML content"
    assert b"TEST0" in resp.data and b"TEST1" in resp.data
    assert b"root@test0.edu" in resp.data
    assert b"5 / 10 (50%)" in resp.data

    resp = client.get("/user_summary?from_date=2017-01-01&to_date=2017-12-31")
    assert resp.status_code == 200
    assert b"<!DOCTYPE html>" in resp.data, "Expected HTML content"
    assert b"TEST0" in resp.data
    assert b"root@test0.edu" in resp.data
    assert b"0 / 10 (0%)" in resp.data

    for (sort, desc) in [(0, 0), (0, 1), (1, 0), (1, 1)]:
        resp = client.get(f"/user_summary?from_date=2017-01-01&to_date=2018-12-31&sort={sort}&desc={desc}")
        assert resp.status_code == 200
        data = resp.data.decode()
        assert f"&sort={0 if sort else 1}&desc=0" in data
        assert f"&sort={sort}&desc={0 if desc else 1}" in data

    resp = client.get("/user_summary")
    assert resp.status_code == 302


def test_user_cv(client, mocker):
    """Test user CV."""
    user0 = User.get(email="root@test0.edu")
    client.login(user0)
    resp = client.get("/user_cv")
    assert resp.status_code == 302
    client.logout()

    user = User.get(email="researcher101@test1.edu")
    client.login(user, follow_redirects=True)

    resp = client.get("/user_cv")
    assert resp.status_code == 302
    url = urlparse(resp.location)
    assert url.path == '/link'

    OrcidToken.create(
        access_token="ABC12345678901",
        user=user,
        org=user.organisation,
        scopes="/scope/read-limited")

    mocker.patch("orcid_hub.reports.MemberAPI.get_record", side_effect=Exception("ERROR!!!"))
    resp = client.get("/user_cv", follow_redirects=True)
    assert resp.status_code == 200
    assert b"iframe" not in resp.data
    assert b"ERROR!!!" in resp.data

    get_record = mocker.patch(
        "orcid_hub.reports.MemberAPI.get_record",
        return_value=json.loads(
            json.dumps({
                "orcid-identifier": {
                    "uri": "http://sandbox.orcid.org/0000-0001-7027-8698",
                    "path": "0000-0001-7027-8698",
                    "host": "sandbox.orcid.org"
                },
                "preferences": {
                    "locale": "EN"
                },
                "history": {
                    "creation-method": "MEMBER_REFERRED",
                    "completion-date": None,
                    "submission-date": {
                        "value": 1505964892638
                    },
                    "last-modified-date": {
                        "value": 1505965202659
                    },
                    "claimed": True,
                    "source": None,
                    "deactivation-date": None,
                    "verified-email": False,
                    "verified-primary-email": False
                },
                "person": {
                    "last-modified-date": {
                        "value": 1505964892861
                    },
                    "name": {
                        "created-date": {
                            "value": 1505964892638
                        },
                        "last-modified-date": {
                            "value": 1505964892861
                        },
                        "given-names": {
                            "value": "Sally"
                        },
                        "family-name": {
                            "value": "Simpsond"
                        },
                        "credit-name": None,
                        "source": None,
                        "visibility": "PUBLIC",
                        "path": "0000-0001-7027-8698"
                    },
                    "other-names": {
                        "last-modified-date": None,
                        "other-name": [],
                        "path": "/0000-0001-7027-8698/other-names"
                    },
                    "biography": None,
                    "researcher-urls": {
                        "last-modified-date": None,
                        "researcher-url": [],
                        "path": "/0000-0001-7027-8698/researcher-urls"
                    },
                    "emails": {
                        "last-modified-date": {
                            "value": 1505964892861
                        },
                        "email": [{
                            "created-date": {
                                "value": 1505964892861
                            },
                            "last-modified-date": {
                                "value": 1505964892861
                            },
                            "source": {
                                "source-orcid": {
                                    "uri": "http://sandbox.orcid.org/0000-0001-7027-8698",
                                    "path": "0000-0001-7027-8698",
                                    "host": "sandbox.orcid.org"
                                },
                                "source-client-id": None,
                                "source-name": {
                                    "value": "Sally Simpson"
                                }
                            },
                            "email": "researcher101@test1.edu",
                            "path": None,
                            "visibility": "LIMITED",
                            "verified": False,
                            "primary": True,
                            "put-code": None
                        }],
                        "path":
                        "/0000-0001-7027-8698/email"
                    },
                    "addresses": {
                        "last-modified-date": None,
                        "address": [],
                        "path": "/0000-0001-7027-8698/address"
                    },
                    "keywords": {
                        "last-modified-date": None,
                        "keyword": [],
                        "path": "/0000-0001-7027-8698/keywords"
                    },
                    "external-identifiers": {
                        "last-modified-date": None,
                        "external-identifier": [],
                        "path": "/0000-0001-7027-8698/external-identifiers"
                    },
                    "path": "/0000-0001-7027-8698/person"
                },
                "activities-summary": {
                    "last-modified-date": None,
                    "educations": {
                        "last-modified-date": None,
                        "education-summary": [],
                        "path": "/0000-0001-7027-8698/educations"
                    },
                    "employments": {
                        "last-modified-date": None,
                        "employment-summary": [],
                        "path": "/0000-0001-7027-8698/employments"
                    },
                    "fundings": {
                        "last-modified-date": None,
                        "group": [],
                        "path": "/0000-0001-7027-8698/fundings"
                    },
                    "peer-reviews": {
                        "last-modified-date": None,
                        "group": [],
                        "path": "/0000-0001-7027-8698/peer-reviews"
                    },
                    "works": {
                        "last-modified-date": None,
                        "group": [],
                        "path": "/0000-0001-7027-8698/works"
                    },
                    "path": "/0000-0001-7027-8698/activities"
                },
                "path": "/0000-0001-7027-8698"
            }),
            object_pairs_hook=NestedDict))

    resp = client.get("/user_cv")
    assert resp.status_code == 200
    assert b"iframe" in resp.data
    assert user.first_name.encode() not in resp.data

    resp = client.get("/user_cv/show")
    assert resp.status_code == 200
    assert user.name.encode() in resp.data
    get_record.assert_called_once_with()

    get_record.reset_mock()
    resp = client.get("/user_cv/download")
    assert resp.status_code == 200
    assert user.name.replace(' ', '_') in resp.headers["Content-Disposition"]
    assert b"content.xml" in resp.data
    get_record.asser_not_called()



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class GroupIdRecords(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, last_modified_date=None, total=None, page=None, page_size=None, group_id_record=None):
        """
        GroupIdRecords - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'last_modified_date': 'LastModifiedDate',
            'total': 'int',
            'page': 'int',
            'page_size': 'int',
            'group_id_record': 'list[GroupIdRecord]'
        }

        self.attribute_map = {
            'last_modified_date': 'last-modified-date',
            'total': 'total',
            'page': 'page',
            'page_size': 'page-size',
            'group_id_record': 'group-id-record'
        }

        self._last_modified_date = last_modified_date
        self._total = total
        self._page = page
        self._page_size = page_size
        self._group_id_record = group_id_record

    @property
    def last_modified_date(self):
        """
        Gets the last_modified_date of this GroupIdRecords.

        :return: The last_modified_date of this GroupIdRecords.
        :rtype: LastModifiedDate
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """
        Sets the last_modified_date of this GroupIdRecords.

        :param last_modified_date: The last_modified_date of this GroupIdRecords.
        :type: LastModifiedDate
        """

        self._last_modified_date = last_modified_date

    @property
    def total(self):
        """
        Gets the total of this GroupIdRecords.

        :return: The total of this GroupIdRecords.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this GroupIdRecords.

        :param total: The total of this GroupIdRecords.
        :type: int
        """
        if total is None:
            raise ValueError("Invalid value for `total`, must not be `None`")

        self._total = total

    @property
    def page(self):
        """
        Gets the page of this GroupIdRecords.

        :return: The page of this GroupIdRecords.
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """
        Sets the page of this GroupIdRecords.

        :param page: The page of this GroupIdRecords.
        :type: int
        """
        if page is None:
            raise ValueError("Invalid value for `page`, must not be `None`")

        self._page = page

    @property
    def page_size(self):
        """
        Gets the page_size of this GroupIdRecords.

        :return: The page_size of this GroupIdRecords.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this GroupIdRecords.

        :param page_size: The page_size of this GroupIdRecords.
        :type: int
        """
        if page_size is None:
            raise ValueError("Invalid value for `page_size`, must not be `None`")

        self._page_size = page_size

    @property
    def group_id_record(self):
        """
        Gets the group_id_record of this GroupIdRecords.

        :return: The group_id_record of this GroupIdRecords.
        :rtype: list[GroupIdRecord]
        """
        return self._group_id_record

    @group_id_record.setter
    def group_id_record(self, group_id_record):
        """
        Sets the group_id_record of this GroupIdRecords.

        :param group_id_record: The group_id_record of this GroupIdRecords.
        :type: list[GroupIdRecord]
        """

        self._group_id_record = group_id_record

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, GroupIdRecords):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Funding(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, created_date=None, last_modified_date=None, source=None, put_code=None, path=None, type=None, organization_defined_type=None, title=None, short_description=None, amount=None, url=None, start_date=None, end_date=None, external_ids=None, contributors=None, organization=None, visibility=None):
        """
        Funding - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'created_date': 'CreatedDate',
            'last_modified_date': 'LastModifiedDate',
            'source': 'Source',
            'put_code': 'int',
            'path': 'str',
            'type': 'str',
            'organization_defined_type': 'OrganizationDefinedFundingSubType',
            'title': 'FundingTitle',
            'short_description': 'str',
            'amount': 'Amount',
            'url': 'Url',
            'start_date': 'FuzzyDate',
            'end_date': 'FuzzyDate',
            'external_ids': 'ExternalIDs',
            'contributors': 'FundingContributors',
            'organization': 'Organization',
            'visibility': 'str'
        }

        self.attribute_map = {
            'created_date': 'created-date',
            'last_modified_date': 'last-modified-date',
            'source': 'source',
            'put_code': 'put-code',
            'path': 'path',
            'type': 'type',
            'organization_defined_type': 'organization-defined-type',
            'title': 'title',
            'short_description': 'short-description',
            'amount': 'amount',
            'url': 'url',
            'start_date': 'start-date',
            'end_date': 'end-date',
            'external_ids': 'external-ids',
            'contributors': 'contributors',
            'organization': 'organization',
            'visibility': 'visibility'
        }

        self._created_date = created_date
        self._last_modified_date = last_modified_date
        self._source = source
        self._put_code = put_code
        self._path = path
        self._type = type
        self._organization_defined_type = organization_defined_type
        self._title = title
        self._short_description = short_description
        self._amount = amount
        self._url = url
        self._start_date = start_date
        self._end_date = end_date
        self._external_ids = external_ids
        self._contributors = contributors
        self._organization = organization
        self._visibility = visibility

    @property
    def created_date(self):
        """
        Gets the created_date of this Funding.

        :return: The created_date of this Funding.
        :rtype: CreatedDate
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this Funding.

        :param created_date: The created_date of this Funding.
        :type: CreatedDate
        """

        self._created_date = created_date

    @property
    def last_modified_date(self):
        """
        Gets the last_modified_date of this Funding.

        :return: The last_modified_date of this Funding.
        :rtype: LastModifiedDate
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """
        Sets the last_modified_date of this Funding.

        :param last_modified_date: The last_modified_date of this Funding.
        :type: LastModifiedDate
        """

        self._last_modified_date = last_modified_date

    @property
    def source(self):
        """
        Gets the source of this Funding.

        :return: The source of this Funding.
        :rtype: Source
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this Funding.

        :param source: The source of this Funding.
        :type: Source
        """

        self._source = source

    @property
    def put_code(self):
        """
        Gets the put_code of this Funding.

        :return: The put_code of this Funding.
        :rtype: int
        """
        return self._put_code

    @put_code.setter
    def put_code(self, put_code):
        """
        Sets the put_code of this Funding.

        :param put_code: The put_code of this Funding.
        :type: int
        """

        self._put_code = put_code

    @property
    def path(self):
        """
        Gets the path of this Funding.

        :return: The path of this Funding.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this Funding.

        :param path: The path of this Funding.
        :type: str
        """

        self._path = path

    @property
    def type(self):
        """
        Gets the type of this Funding.

        :return: The type of this Funding.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Funding.

        :param type: The type of this Funding.
        :type: str
        """
        allowed_values = ["GRANT", "CONTRACT", "AWARD", "SALARY_AWARD"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def organization_defined_type(self):
        """
        Gets the organization_defined_type of this Funding.

        :return: The organization_defined_type of this Funding.
        :rtype: OrganizationDefinedFundingSubType
        """
        return self._organization_defined_type

    @organization_defined_type.setter
    def organization_defined_type(self, organization_defined_type):
        """
        Sets the organization_defined_type of this Funding.

        :param organization_defined_type: The organization_defined_type of this Funding.
        :type: OrganizationDefinedFundingSubType
        """

        self._organization_defined_type = organization_defined_type

    @property
    def title(self):
        """
        Gets the title of this Funding.

        :return: The title of this Funding.
        :rtype: FundingTitle
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this Funding.

        :param title: The title of this Funding.
        :type: FundingTitle
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")

        self._title = title

    @property
    def short_description(self):
        """
        Gets the short_description of this Funding.

        :return: The short_description of this Funding.
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """
        Sets the short_description of this Funding.

        :param short_description: The short_description of this Funding.
        :type: str
        """

        self._short_description = short_description

    @property
    def amount(self):
        """
        Gets the amount of this Funding.

        :return: The amount of this Funding.
        :rtype: Amount
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this Funding.

        :param amount: The amount of this Funding.
        :type: Amount
        """

        self._amount = amount

    @property
    def url(self):
        """
        Gets the url of this Funding.

        :return: The url of this Funding.
        :rtype: Url
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this Funding.

        :param url: The url of this Funding.
        :type: Url
        """

        self._url = url

    @property
    def start_date(self):
        """
        Gets the start_date of this Funding.

        :return: The start_date of this Funding.
        :rtype: FuzzyDate
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this Funding.

        :param start_date: The start_date of this Funding.
        :type: FuzzyDate
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this Funding.

        :return: The end_date of this Funding.
        :rtype: FuzzyDate
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this Funding.

        :param end_date: The end_date of this Funding.
        :type: FuzzyDate
        """

        self._end_date = end_date

    @property
    def external_ids(self):
        """
        Gets the external_ids of this Funding.

        :return: The external_ids of this Funding.
        :rtype: ExternalIDs
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """
        Sets the external_ids of this Funding.

        :param external_ids: The external_ids of this Funding.
        :type: ExternalIDs
        """

        self._external_ids = external_ids

    @property
    def contributors(self):
        """
        Gets the contributors of this Funding.

        :return: The contributors of this Funding.
        :rtype: FundingContributors
        """
        return self._contributors

    @contributors.setter
    def contributors(self, contributors):
        """
        Sets the contributors of this Funding.

        :param contributors: The contributors of this Funding.
        :type: FundingContributors
        """

        self._contributors = contributors

    @property
    def organization(self):
        """
        Gets the organization of this Funding.

        :return: The organization of this Funding.
        :rtype: Organization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this Funding.

        :param organization: The organization of this Funding.
        :type: Organization
        """
        if organization is None:
            raise ValueError("Invalid value for `organization`, must not be `None`")

        self._organization = organization

    @property
    def visibility(self):
        """
        Gets the visibility of this Funding.

        :return: The visibility of this Funding.
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """
        Sets the visibility of this Funding.

        :param visibility: The visibility of this Funding.
        :type: str
        """
        allowed_values = ["LIMITED", "REGISTERED_ONLY", "PUBLIC", "PRIVATE"]
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Funding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.external_i_ds_v30 import ExternalIDsV30  # noqa: F401,E501
from orcid_api_v3.models.research_resource_hosts_v30 import ResearchResourceHostsV30  # noqa: F401,E501
from orcid_api_v3.models.url_v30 import UrlV30  # noqa: F401,E501


class ResearchResourceItemV30(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_name': 'str',
        'resource_type': 'str',
        'hosts': 'ResearchResourceHostsV30',
        'external_ids': 'ExternalIDsV30',
        'url': 'UrlV30'
    }

    attribute_map = {
        'resource_name': 'resource-name',
        'resource_type': 'resource-type',
        'hosts': 'hosts',
        'external_ids': 'external-ids',
        'url': 'url'
    }

    def __init__(self, resource_name=None, resource_type=None, hosts=None, external_ids=None, url=None):  # noqa: E501
        """ResearchResourceItemV30 - a model defined in Swagger"""  # noqa: E501
        self._resource_name = None
        self._resource_type = None
        self._hosts = None
        self._external_ids = None
        self._url = None
        self.discriminator = None
        if resource_name is not None:
            self.resource_name = resource_name
        if resource_type is not None:
            self.resource_type = resource_type
        if hosts is not None:
            self.hosts = hosts
        if external_ids is not None:
            self.external_ids = external_ids
        if url is not None:
            self.url = url

    @property
    def resource_name(self):
        """Gets the resource_name of this ResearchResourceItemV30.  # noqa: E501


        :return: The resource_name of this ResearchResourceItemV30.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this ResearchResourceItemV30.


        :param resource_name: The resource_name of this ResearchResourceItemV30.  # noqa: E501
        :type: str
        """

        self._resource_name = resource_name

    @property
    def resource_type(self):
        """Gets the resource_type of this ResearchResourceItemV30.  # noqa: E501


        :return: The resource_type of this ResearchResourceItemV30.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ResearchResourceItemV30.


        :param resource_type: The resource_type of this ResearchResourceItemV30.  # noqa: E501
        :type: str
        """
        allowed_values = ["infrastructures", "collections", "equipment", "services"]  # noqa: E501
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def hosts(self):
        """Gets the hosts of this ResearchResourceItemV30.  # noqa: E501


        :return: The hosts of this ResearchResourceItemV30.  # noqa: E501
        :rtype: ResearchResourceHostsV30
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this ResearchResourceItemV30.


        :param hosts: The hosts of this ResearchResourceItemV30.  # noqa: E501
        :type: ResearchResourceHostsV30
        """

        self._hosts = hosts

    @property
    def external_ids(self):
        """Gets the external_ids of this ResearchResourceItemV30.  # noqa: E501


        :return: The external_ids of this ResearchResourceItemV30.  # noqa: E501
        :rtype: ExternalIDsV30
        """
        return self._external_ids

    @external_ids.setter
    def external_ids(self, external_ids):
        """Sets the external_ids of this ResearchResourceItemV30.


        :param external_ids: The external_ids of this ResearchResourceItemV30.  # noqa: E501
        :type: ExternalIDsV30
        """

        self._external_ids = external_ids

    @property
    def url(self):
        """Gets the url of this ResearchResourceItemV30.  # noqa: E501


        :return: The url of this ResearchResourceItemV30.  # noqa: E501
        :rtype: UrlV30
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ResearchResourceItemV30.


        :param url: The url of this ResearchResourceItemV30.  # noqa: E501
        :type: UrlV30
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResearchResourceItemV30, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResearchResourceItemV30):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.keyword_v30_rc1 import KeywordV30Rc1  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v30_rc1 import LastModifiedDateV30Rc1  # noqa: F401,E501


class KeywordsV30Rc1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'last_modified_date': 'LastModifiedDateV30Rc1',
        'keyword': 'list[KeywordV30Rc1]',
        'path': 'str'
    }

    attribute_map = {
        'last_modified_date': 'last-modified-date',
        'keyword': 'keyword',
        'path': 'path'
    }

    def __init__(self, last_modified_date=None, keyword=None, path=None):  # noqa: E501
        """KeywordsV30Rc1 - a model defined in Swagger"""  # noqa: E501
        self._last_modified_date = None
        self._keyword = None
        self._path = None
        self.discriminator = None
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if keyword is not None:
            self.keyword = keyword
        if path is not None:
            self.path = path

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this KeywordsV30Rc1.  # noqa: E501


        :return: The last_modified_date of this KeywordsV30Rc1.  # noqa: E501
        :rtype: LastModifiedDateV30Rc1
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this KeywordsV30Rc1.


        :param last_modified_date: The last_modified_date of this KeywordsV30Rc1.  # noqa: E501
        :type: LastModifiedDateV30Rc1
        """

        self._last_modified_date = last_modified_date

    @property
    def keyword(self):
        """Gets the keyword of this KeywordsV30Rc1.  # noqa: E501


        :return: The keyword of this KeywordsV30Rc1.  # noqa: E501
        :rtype: list[KeywordV30Rc1]
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this KeywordsV30Rc1.


        :param keyword: The keyword of this KeywordsV30Rc1.  # noqa: E501
        :type: list[KeywordV30Rc1]
        """

        self._keyword = keyword

    @property
    def path(self):
        """Gets the path of this KeywordsV30Rc1.  # noqa: E501


        :return: The path of this KeywordsV30Rc1.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this KeywordsV30Rc1.


        :param path: The path of this KeywordsV30Rc1.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KeywordsV30Rc1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordsV30Rc1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
